/*
 *****************************************************
 *
 *  SaVi by Robert Thurman (thurman@geom.umn.edu) and
 *          Patrick Worfolk (worfolk@alum.mit.edu).
 *
 *  Copyright (c) 1997 by The Geometry Center.
 *  This file is part of SaVi.  SaVi is free software;
 *  you can redistribute it and/or modify it only under
 *  the terms given in the file COPYRIGHT which you should
 *  have received along with this file.  SaVi may be
 *  obtained by emailing savi@geom.umn.edu.
 *
 *****************************************************
 *
 * main.c
 *
 * $Id: main.c,v 1.2 2002/12/27 21:01:37 lloyd Exp $
 */

#include <stdlib.h>
#include <string.h>
#include <sys/types.h>
#include <time.h>

#include "utils.h"
#include "constants.h"
#include "globals.h"
#include "sats.h"
#include "tcl_utils.h"
#include "gv_utils.h"

static void decode_cmd_line(int argc, char *argv[]);

int
main(int argc, char *argv[])
{
  char buf[] = "main(update)";

  Tcl_FindExecutable(argv[0]);

  /* decode command line */
  decode_cmd_line(argc, argv);

  /* initialize geomview if started as a module */
  if (geomview_module) {
    gv_stream_init_proc();
    if (!gv_init()) {
      error_and_exit("could not initialise Geomview (main: error in gv_init).");
    } else {
      GV_BINARY_FORMAT_AVAILABLE = gv_init_proc();
    }
  } else {
    error("For 3D visualization, run from within Geomview.");
  }

  interp = Tcl_CreateInterp();

  /* initialize Tcl interface */
  if (!tcl_init(interp)) {
    error_and_exit("could not initialise Tcl (main: error in tcl_init).");
  }

  /* initialize Tk interface */
  if (!tk_init(interp)) {
    error_and_exit("could not initialise Tk (main: error in tk_init).");
  }

  /* load up a single satellite */
  sats_init();

  /* and update interface */
  if (!tcl_script(buf)) {
    error_and_exit(
	    "first edit the savi wrapper script to set locations correctly.");
  }
  /* loop until exit */
  while (sats_update() && tk_update());

  Tcl_DeleteInterp(interp);

  exit(0);
}

static void
decode_cmd_line(int argc, char *argv[])
{
  int i;

  for (i = 1; i < argc; i++) {
    if (strcmp(argv[i], "-geomview") == 0) {
      geomview_module = TRUE;
    } else if (strcmp(argv[i], "-nologo") == 0) {
      geomview_logo = FALSE;
    } else if (strcmp(argv[i], "-version") == 0) {
      error(Version);
      exit(0);
    } else {
      /* argv[0] gives name of binary, not wrapper script */
      error("command-line usage is: "
	    "savi [-geomview] [-nologo] [-version]");
    }
  }
}
